@@ -4,8 +4,8 @@ from .abstract_template import AbstractTemplate
 
 class FileTemplate(AbstractTemplate):
     def __init__(self, filename: Union[str, Path], name: Optional[str] = None):
-        file = open(filename, "r")
-        self._string = file.read()
+        with open(filename, "r") as file:
+            self._string = file.read()
         if name is None:
             self.name = str(filename)
         else:
